mysql.exceptions.server.Binlog_Unsafe_Routine

Package mysql :: Package exceptions :: Module server :: Class Binlog_Unsafe_Routine |
[hide private]
[frames] | no frames]

# Class Binlog_Unsafe_Routine

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  Binlog_Unsafe_Routine

This function has none of DETERMINISTIC, NO SQL, or READS SQL DATA in its declaration and binary logging is enabled (you might want to use the less safe log_bin_trust_function_creators variable)

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`